pub enum BuiltinTheme {
CatppuccinMocha,
Cyberpunk,
Dracula,
EverforestDark,
GruvboxDark,
Mono,
Nord,
OneDark,
RosePine,
SolarizedLight,
TokyoNight,
}Expand description
Enum of built in themes.
Variants
CatppuccinMocha
Catppuccin Mocha — dark, pastel-toned.
Cyberpunk
Cyberpunk — high-contrast neon on dark.
Dracula
Dracula — the classic dark purple theme (default).
EverforestDark
Everforest Dark — muted green forest tones.
GruvboxDark
Gruvbox Dark — warm retro earth tones.
Mono
Mono — minimal monochrome.
Nord
Nord — cool arctic blue palette.
OneDark
One Dark — Atom-inspired dark theme.
RosePine
Rosé Pine — soho vibes, muted rose tones.
SolarizedLight
Solarized Light — the classic light theme.
TokyoNight
Tokyo Night — vibrant dark blues and purples.
Implementations
Sourceimpl BuiltinTheme
Built in themes to provide an easy on ramp for users who haven’t installed theme files.
impl BuiltinTheme
Built in themes to provide an easy on ramp for users who haven’t installed theme files.
Sourcepub fn default_light() -> BuiltinTheme
pub fn default_light() -> BuiltinTheme
Returns a nice default light Theme.
Sourcepub fn iter() -> impl Iterator<Item = BuiltinTheme>
pub fn iter() -> impl Iterator<Item = BuiltinTheme>
Iterator to get all the built in themes.