pub struct Palette(/* private fields */);Expand description
Color palette with named hue ramps (TOML section [palette]).
Each ramp is a 0-indexed Vec<String> where values are either
#RRGGBB hex strings or ansi.<key> references.
Ramps should be ordered darkest (index 0) to lightest.
Implementations
Sourceimpl Palette
impl Palette
Sourcepub fn new(map: HashMap<String, Vec<String>>) -> Self
pub fn new(map: HashMap<String, Vec<String>>) -> Self
Create a palette from a map of ramp names to color vectors.
Sourcepub fn get_ramp(&self, name: &str) -> Option<&[String]>
pub fn get_ramp(&self, name: &str) -> Option<&[String]>
Return the named ramp, or None if it doesn’t exist.
Sourcepub fn ramp_names(&self) -> Vec<&str>
pub fn ramp_names(&self) -> Vec<&str>
Return all ramp names in sorted order.